<?php
/**
 * Theme activation.
 *
 * @package Dizibiz
 */
if (!class_exists('Dizibiz_Modules')) {
	/**
	 * Get a svg icon
	 */
	class Dizibiz_Modules
	{

		/**
		 * Constructor
		 */
		public function __construct()
		{
			add_action('admin_init', array($this, 'activate_modules'));
		}


		/**
		 * All modules registered in Dizibiz
		 */
		public static function get_modules()
		{
			$modules = array(
				array(
					'slug' => 'More color options',
					'name' => esc_html__('Color Options', 'dizibiz'),
					'type' => 'pro',
					'link' => 'http://',
					'link_label' => esc_html__('Build templates', 'dizibiz'),
					'activate_uri' => '&amp;activate_module_templates',
					//param is added in dashboard class
					'text' => __('More color options to choose', 'dizibiz'),
				),
				array(
					'slug' => 'More typography options',
					'name' => esc_html__('More Typography Options', 'dizibiz'),
					'type' => 'pro',
					'link' => admin_url('/customize.php?autofocus[panel]=dizibiz_panel_header'),
					'link_label' => esc_html__('Customize', 'dizibiz'),
					'activate_uri' => '&amp;activate_module_ext-header',
					//param is added in dashboard class
					'text' => __('More typography options to choose', 'dizibiz'),
				),
				array(
					'slug' => 'Add-widget options',
					'name' => esc_html__('Additional Widget Options', 'dizibiz'),
					'type' => 'pro',
					'link' => admin_url('/customize.php?autofocus[panel]=woocommerce'),
					'link_label' => esc_html__('Customize', 'dizibiz'),
					'activate_uri' => '&amp;activate_module_ext-woocommerce',
					//param is added in dashboard class
					'text' => __('Additional widget options to choose.', 'dizibiz'),
				),
				array(
					'slug' => 'more customizer',
					'name' => esc_html__('More Customizer Option', 'dizibiz'),
					'type' => 'pro',
					'link' => admin_url('/customize.php?autofocus[panel]=dizibiz_panel_blog'),
					'link_label' => esc_html__('Customize', 'dizibiz'),
					'activate_uri' => '&amp;activate_module_ext-blog',
					//param is added in dashboard class
					'text' => __('More customizer options abailable.', 'dizibiz'),
				),
			);

			return $modules;
		}

		/**
		 * Check if a specific module is activated
		 */
		public static function is_module_active($module)
		{

			$all_modules = get_option('dizibiz-modules');
			$all_modules = (is_array($all_modules)) ? $all_modules : (array) $all_modules;

			if (array_key_exists($module, $all_modules) && true === $all_modules[$module]) {
				return true;
			}

			return false;
		}

		/**
		 * Activate modules on click
		 */
		public function activate_modules()
		{
			$modules = $this->get_modules();

			$all_modules = get_option('dizibiz-modules');
			$all_modules = (is_array($all_modules)) ? $all_modules : (array) $all_modules;

			foreach ($modules as $module) {
				if (isset($_GET['activate_module_' . $module['slug']])) {
					if ('1' == $_GET['activate_module_' . $module['slug']]) {
						update_option('dizibiz-modules', array_merge($all_modules, array($module['slug'] => true)));
					} elseif ('0' == $_GET['activate_module_' . $module['slug']]) {
						update_option('dizibiz-modules', array_merge($all_modules, array($module['slug'] => false)));
					}
				}
			}
		}
	}
}

new Dizibiz_Modules();
/**
 * Theme Dashboard [Free VS Pro]
 */
function dizibiz_free_vs_pro_html()
{
	ob_start();
	?>
	<div class="theme-admin-title">
		<?php esc_html_e('Differences between Dizibiz and Dizibiz Pro', 'dizibiz'); ?>
	</div>
	<div class="theme-admin-description">
		<?php esc_html_e('Here are some of the differences between Dizibiz and Dizibiz Pro:', 'dizibiz'); ?>
	</div>

	<table class="thd-table-compare">
		<thead>
			<tr>
				<th>
					<?php esc_html_e('Feature', 'dizibiz'); ?>
				</th>
				<th>
					<?php esc_html_e('Dizibiz', 'dizibiz'); ?>
				</th>
				<th>
					<?php esc_html_e('Dizibiz Pro', 'dizibiz'); ?>
				</th>
			</tr>
		</thead>
		<tbody>
			<tr>
				<td>
					<?php esc_html_e('Access to all Google Fonts', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Gutenberg Ready', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Logo and Title Customization', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Color Options', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-tertiary"><i
							class="dashicons dashicons-no-alt"></i></span></td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Font Family Options', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-tertiary"><i
							class="dashicons dashicons-no-alt"></i></span></td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Fullwidth Layout', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Boxed Layout', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-tertiary"><i
							class="dashicons dashicons-no-alt"></i></span></td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Breadcrumbs', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Mailchimp Subscription', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-tertiary"><i
							class="dashicons dashicons-no-alt"></i></span></td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Single Page/Post Control', 'dizibiz'); ?>
				</td>
				<td><span> Limited controls </span></td>
				<td><span> Multiple control </span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Archive Control', 'dizibiz'); ?>
				</td>
				<td><span> Limited controls </span></td>
				<td><span> Multiple control </span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Translation', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Instagram Direct Feeds', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-tertiary"><i
							class="dashicons dashicons-no-alt"></i></span></td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Theme Credit Link', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-tertiary"><i
							class="dashicons dashicons-no-alt"></i></span></td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Footer Widgets', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Preloader Option', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Social Profile Options', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Social Share', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Google Adsense', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Seo', 'dizibiz'); ?>
				</td>
				<td><span>Compatible</span>
				</td>
				<td><span>Compatible</span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('WooCommerce', 'dizibiz'); ?>
				</td>
				<td><span>Compatible</span>
				</td>
				<td><span>Compatible</span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Elementor Page Builder', 'dizibiz'); ?>
				</td>
				<td><span>Compatible</span>
				</td>
				<td><span>Compatible</span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Support', 'dizibiz'); ?>
				</td>
				<td><span>Yes</span>
				</td>
				<td><span>High Priority Dedicated Support</span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Responsive', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Sticky and transparent menu', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Multiple blog layouts', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
			<tr>
				<td>
					<?php esc_html_e('Footer credits', 'dizibiz'); ?>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
				<td><span class="theme-dashboard-badge theme-badge-primary"><i class="dashicons dashicons-saved"></i></span>
				</td>
			</tr>
		</tbody>
	</table>

	<div class="theme-admin-separator"></div>

	<h4>
		<a href="https://www.themeinwp.com/theme/dizibiz" target="_blank">
			<?php esc_html_e('Full list of differences between Dizibiz and Dizibiz Pro', 'dizibiz'); ?>
		</a>
	</h4>

	<div class="theme-admin-separator"></div>

	<div class="theme-admin-button-wrap">
		<a href="https://www.themeinwp.com/theme/dizibiz" class="button theme-admin-button admin-button-primary">
			<?php esc_html_e('Get Dizibiz Pro Today', 'dizibiz'); ?>
		</a>
	</div>
	<?php
	return ob_get_clean();
}

/**
 * Theme Dashboard Settings
 *
 * @param array $settings The settings.
 */
function dizibiz_dashboard_settings($settings)
{

	// Starter.

	// Hero.
	$settings['hero_title'] = esc_html__('Welcome to Dizibiz', 'dizibiz');
	$settings['hero_themes_desc'] = esc_html__('Dizibiz is now installed and ready to use. Click on Starter Sites to get off to a flying start with one of our pre-made templates, or go to Theme Dashboard to get an overview of everything.', 'dizibiz');
	$settings['hero_desc'] = esc_html__('Dizibiz is now installed and ready to go. To help you with the next step, we\'ve gathered together on this page all the resources you might need. We hope you enjoy using Dizibiz.', 'dizibiz');
	$settings['hero_image'] = get_template_directory_uri() . '/inc/admin/dashboard/images/welcome-banner@2x.png';

	// Tabs.
	$settings['tabs'] = array(
		array(
			'name' => esc_html__('Theme Features', 'dizibiz'),
			'type' => 'features',
			'visible' => array('free', 'pro'),
			'data' => array(
				array(
					'name' => esc_html__('Header media', 'dizibiz'),
					'type' => 'free',
					'customize_uri' => admin_url('/customize.php?autofocus[section]=header_image'),
				),
				array(
					'name' => esc_html__('Change Site Title or Logo', 'dizibiz'),
					'type' => 'free',
					'customize_uri' => admin_url('/customize.php?autofocus[section]=title_tagline'),
				),
				array(
					'name' => esc_html__('Header Options', 'dizibiz'),
					'type' => 'free',
					'customize_uri' => admin_url('/customize.php?autofocus[section]=header_options'),
				),
				array(
					'name' => esc_html__('Color Options', 'dizibiz'),
					'type' => 'free',
					'customize_uri' => admin_url('/customize.php?autofocus[section]=colors'),
				),
				array(
					'name' => esc_html__('Archive Options', 'dizibiz'),
					'type' => 'free',
					'customize_uri' => admin_url('/customize.php?autofocus[section]=archive_options'),
				),
				array(
					'name' => esc_html__('Single Options', 'dizibiz'),
					'type' => 'free',
					'customize_uri' => admin_url('/customize.php?autofocus[section]=single_options'),
				),
				array(
					'name' => esc_html__('Footer options', 'dizibiz'),
					'type' => 'free',
					'customize_uri' => admin_url('/customize.php?autofocus[section]=footer_options'),
				),
				array(
					'name' => esc_html__('Dark mode options', 'dizibiz'),
					'type' => 'free',
					'customize_uri' => admin_url('/customize.php?autofocus[section]=dark_mode_options'),
				),
				array(
					'name' => esc_html__('Widget options', 'dizibiz'),
					'type' => 'free',
					'customize_uri' => admin_url('/customize.php?autofocus[panel]=widgets'),
				),
				array(
					'name' => esc_html__('Menu options', 'dizibiz'),
					'type' => 'free',
					'customize_uri' => admin_url('/customize.php?autofocus[panel]=nav_menus'),
				),
			),
		),
		array(
			'name' => esc_html__('Free vs PRO', 'dizibiz'),
			'type' => 'html',
			'visible' => array('free'),
			'data' => dizibiz_free_vs_pro_html(),
		)
	);

	//Insert modules
	$settings['tabs'][0]['data'] = array_merge($settings['tabs'][0]['data'], Dizibiz_Modules::get_modules());

	$settings['tabs'][0]['data'] = array_merge(
		$settings['tabs'][0]['data'],
		array(
			array(
				'name' => esc_html__('Extra Widget Area', 'dizibiz'),
				'type' => 'pro',
				'customize_uri' => '/wp-admin/customize.php?autofocus[section]=dizibiz_extra_widget_area',
			),
			array(
				'name' => esc_html__('Google Maps', 'dizibiz'),
				'type' => 'pro',
				'customize_uri' => '/wp-admin/customize.php?autofocus[section]=dizibiz_pro_maps',
			),
		)
	);

	// Documentation.
	$settings['documentation_link'] = 'https://docs.themeinwp.com';

	// Promo.
	$settings['promo_title'] = esc_html__('Upgrade to Pro', 'dizibiz');
	$settings['promo_desc'] = esc_html__('Take Dizibiz to a whole other level by upgrading to the Pro version.', 'dizibiz');
	$settings['promo_button'] = esc_html__('Discover Dizibiz Pro', 'dizibiz');
	$settings['promo_link'] = 'https://themeinwp.com/theme/dizibiz-pro';

	// Review.
	$settings['review_link'] = 'https://wordpress.org/support/theme/dizibiz/reviews/';
	$settings['suggest_idea_link'] = 'https://themeinwp.com/dizbiz/';

	// Support.
	$settings['support_link'] = 'https://wordpress.org/support/theme/dizibiz/';
	$settings['support_pro_link'] = 'https://www.themeinwp.com/support/';

	// Community.
	$settings['community_link'] = 'https://www.facebook.com/themeinwp/';

	$theme = wp_get_theme();
	// Changelog.
	$settings['changelog_version'] = $theme->version;
	$settings['changelog_link'] = 'https://themeinwp.com/changelog/dizibiz/';

	return $settings;
}
add_filter('thd_register_settings', 'dizibiz_dashboard_settings');