<?php

if (!defined('ABSPATH')) {
    exit;
}

class Dizibiz_Call_To_Action extends Dizibiz_Widget_Base
{
    /**
     * Constructor.
     */
    public function __construct()
    {
        $this->widget_cssclass = 'widget_dizibiz_call_to_action';
        $this->widget_description = __("Adds Call to action section", 'dizibiz');
        $this->widget_id = 'dizibiz_call_to_action';
        $this->widget_name = __('Dizibiz: Call To Action', 'dizibiz');

        $this->settings = array(
            'title' => array(
                'type' => 'text',
                'label' => __('Widget Title', 'dizibiz'),
            ),
            'title_text' => array(
                'type' => 'text',
                'label' => __('CTA Title', 'dizibiz'),
            ),
            'desc'  => array(
                'type'  => 'textarea',
                'label' => __('CTA Description', 'dizibiz'),
                'rows' => 10,
            ),
            'bg_image'  => array(
                'type'  => 'image',
                'label' => __('Background Image', 'dizibiz'),
            ),
            'btn_text'  => array(
                'type'  => 'text',
                'label' => __('Button Text', 'dizibiz'),
            ),
            'btn_link'  => array(
                'type'  => 'url',
                'label' => __('Link to url', 'dizibiz'),
                'desc' => __('Enter a proper url with http: OR https:', 'dizibiz'),
            ),
            'link_target'  => array(
                'type'  => 'checkbox',
                'label' => __('Open Link in new Tab', 'dizibiz'),
                'std' => true,
            ),
            'msg' => array(
                'type' => 'message',
                'label' => __('Additonal Settings', 'dizibiz'),
            ),
            'enable_fixed_bg'  => array(
                'type'  => 'checkbox',
                'label' => __('Enable Fixed Background Image', 'dizibiz'),
                'std' => true,
            ),
            'bg_overlay_color' => array(
                'type' => 'color',
                'label' => __('Overlay Color', 'dizibiz'),
                'std' => '#000000',
            ),
            'overlay_opacity'  => array(
                'type' => 'number',
                'step' => 10,
                'min' => 0,
                'max' => 100,
                'std' => 50,
                'label' => __('Overlay Opacity (Default 50%)', 'dizibiz'),
            ),
        );

        parent::__construct();
    }

    /**
     * Output widget.
     *
     * @see WP_Widget
     *
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance)
    {
        ob_start();

        $this->widget_start($args, $instance);

        do_action('dizibiz_before_cta');

?>

        <div class="cta-content-container">
            <?php if ($instance['bg_image'] && 0 != $instance['bg_image']) : ?>

                <?php
                $style = 'background-color:' . $instance['bg_overlay_color'] . ';';
                $style .= 'opacity:' . ($instance['overlay_opacity'] / 100) . ';';
                ?>

                <div class="dizibiz-cta-widget dizibiz-cover-block data-bg data-bg-medium <?php echo ($instance['enable_fixed_bg']) ? 'dizibiz-bg-image dizibiz-bg-attachment-fixed' : ''; ?>">

                    <span aria-hidden="true" class="dizibiz-block-overlay" style="<?php echo esc_attr($style); ?>"></span>

                    <?php echo wp_get_attachment_image($instance['bg_image'], 'full'); ?>
                </div>

            <?php endif; ?>

            <div class="dizibiz-cta-inner-wrapper dizibiz-block-inner-wrapper">

                <?php if ($instance['title_text']) : ?>
                    <div class="cta-title">
                        <?php echo esc_html($instance['title_text']); ?>
                    </div>
                <?php endif; ?>

                <?php if ($instance['desc']) : ?>
                    <div class="cta-description">
                        <?php echo wpautop(wp_kses_post($instance['desc'])); ?>
                    </div>
                <?php endif; ?>

                <?php if ($instance['btn_text']) : ?>
                    <div class="theme-primary-btn">
                        <a href="<?php echo ($instance['btn_link']) ? esc_url($instance['btn_link']) : ''; ?>" target="<?php echo ($instance['link_target']) ? "_blank" : '_self'; ?>" class="button theme-primary-btn"><?php echo esc_html(($instance['btn_text'])); ?></a>
                    </div>
                <?php endif; ?>

            </div>
        </div>

<?php

        do_action('dizibiz_after_cta');

        $this->widget_end($args);

        echo ob_get_clean();
    }
}
