<?php

if (!defined('ABSPATH')) {
    exit;
}

class Dizibiz_Mailchimp_Form extends Dizibiz_Widget_Base
{

    /**
     * Constructor.
     */
    public function __construct()
    {
        $this->widget_cssclass = 'widget_dizibiz_mailchimp_form';
        $this->widget_description = __("Displays MailChimp form if you have any", 'dizibiz');
        $this->widget_id = 'dizibiz_mailchimp_form';
        $this->widget_name = __('Dizibiz: MailChimp Form', 'dizibiz');
        $this->settings = array(
            'title' => array(
                'type' => 'text',
                'label' => __('Title', 'dizibiz'),
            ),
            'desc' => array(
                'type' => 'textarea',
                'label' => __('Description', 'dizibiz'),
                'rows' => 10,
            ),
            'form_shortcode' => array(
                'type' => 'text',
                'label' => __('MailChimp Form Shortcode', 'dizibiz'),
            ),
            'style' => array(
                'type' => 'select',
                'label' => __('Style', 'dizibiz'),
                'options' => array(
                    'style_1' => __('Style 1', 'dizibiz'),
                    'style_2' => __('Style 2', 'dizibiz'),
                    'style_3' => __('Style 3', 'dizibiz'),
                ),
                'std' => 'style_1',
            ),
            'msg' => array(
                'type' => 'message',
                'label' => __('Additonal Settings', 'dizibiz'),
            ),
            'bg_image'  => array(
                'type'  => 'image',
                'label' => __( 'Background Image', 'dizibiz' ),
                'desc' => __( 'Don\'t upload any image if you do not want to show the background image.', 'dizibiz' ),
            ),
            'enable_fixed_bg'  => array(
                'type'  => 'checkbox',
                'label' => __( 'Enable Fixed Background Image', 'dizibiz' ),
                'std' => true,
            ),
            'bg_overlay_color' => array(
                'type' => 'color',
                'label' => __( 'Overlay Color', 'dizibiz' ),
                'std' => '#000000',
            ),
            'overlay_opacity'  => array(
                'type' => 'number',
                'step' => 10,
                'min' => 0,
                'max' => 100,
                'std' => 50,
                'label' => __('Overlay Opacity (Default 50%)', 'dizibiz'),
            ),
        );
        parent::__construct();
    }

    /**
     * Output widget.
     *
     * @see WP_Widget
     *
     * @param array $args
     * @param array $instance
     */
    public function widget($args, $instance)
    {
        if (!empty($instance['form_shortcode'])) {

            ob_start();

            $class = '';

            $image_enabled = false;

            $this->widget_start($args, $instance);

            if($instance['bg_image'] && 0 != $instance['bg_image']){
                $image_enabled = true;
                $class = 'dizibiz-cover-block ';

                if($instance['enable_fixed_bg']){
                    $class .= 'dizibiz-bg-image dizibiz-bg-attachment-fixed ';
                }
            }

            $class .= $instance['style'];

            do_action( 'dizibiz_before_mailchimp');

            ?>
            <div class="dizibiz-mailchimp-widget <?php echo esc_attr($class);?>">

                <?php
                if($image_enabled){
                    $style = 'background-color:'.$instance['bg_overlay_color'].';';  
                    $style .= 'opacity:'.($instance['overlay_opacity']/100).';';
                    ?>
                    <span aria-hidden="true" class="dizibiz-block-overlay" style="<?php echo esc_attr($style);?>"></span>
                    <?php echo wp_get_attachment_image($instance['bg_image'],'full');?>
                    <?php
                }
                ?>
                <div class="dizibiz-mailchimp-inner-wrapper dizibiz-block-inner-wrapper">
                    <div class="mailchimp-desc">
                        <?php
                        if ($instance['desc']) {
                            echo wpautop(wp_kses_post($instance['desc']));
                        }
                        ?>
                    </div>
                    <?php echo do_shortcode($instance['form_shortcode']); ?>
                </div>

            </div>

            <?php

            do_action( 'dizibiz_after_mailchimp');

            $this->widget_end($args);

            echo ob_get_clean();
        }
    }
}