<?php
if (!defined('ABSPATH')) {
    exit;
}

class Dizibiz_Portfolio_Widget extends Dizibiz_Widget_Base
{
    /**
     * Sets up a new widget instance.
     *
     * @since 1.0.0
     */
    public function __construct()
    {
        $this->widget_cssclass = 'widget_dizibiz_portfolio_posts';
        $this->widget_description = __("Displays portfolio section with an image", 'dizibiz');
        $this->widget_id = 'dizibiz_portfolio_posts';
        $this->widget_name = __('Dizibiz: Portfolio Section', 'dizibiz');
        $this->settings = array(
            'title' => array(
                'type' => 'text',
                'label' => __('Title', 'dizibiz'),
            ),
            'description' => array(
                'type' => 'textarea',
                'label' => __('Section Description', 'dizibiz'),
            ),
            'category_1' => array(
                'type' => 'dropdown-taxonomies',
                'label' => __('Select Category 1', 'dizibiz'),
                'desc' => __('Leave empty if you don\'t want the posts to be category specific', 'dizibiz'),
                'args' => array(
                    'taxonomy' => 'category',
                    'class' => 'widefat',
                    'hierarchical' => true,
                    'show_count' => 1,
                    'show_option_all' => __('&mdash; Select &mdash;', 'dizibiz'),
                ),
            ),
            'category_2' => array(
                'type' => 'dropdown-taxonomies',
                'label' => __('Select Category 2', 'dizibiz'),
                'desc' => __('Leave empty if you don\'t want the posts to be category specific', 'dizibiz'),
                'args' => array(
                    'taxonomy' => 'category',
                    'class' => 'widefat',
                    'hierarchical' => true,
                    'show_count' => 1,
                    'show_option_all' => __('&mdash; Select &mdash;', 'dizibiz'),
                ),
            ),
            'category_3' => array(
                'type' => 'dropdown-taxonomies',
                'label' => __('Select Category 3', 'dizibiz'),
                'desc' => __('Leave empty if you don\'t want the posts to be category specific', 'dizibiz'),
                'args' => array(
                    'taxonomy' => 'category',
                    'class' => 'widefat',
                    'hierarchical' => true,
                    'show_count' => 1,
                    'show_option_all' => __('&mdash; Select &mdash;', 'dizibiz'),
                ),
            ),
            'category_4' => array(
                'type' => 'dropdown-taxonomies',
                'label' => __('Select Category 4', 'dizibiz'),
                'desc' => __('Leave empty if you don\'t want the posts to be category specific', 'dizibiz'),
                'args' => array(
                    'taxonomy' => 'category',
                    'class' => 'widefat',
                    'hierarchical' => true,
                    'show_count' => 1,
                    'show_option_all' => __('&mdash; Select &mdash;', 'dizibiz'),
                ),
            ),

        );
        parent::__construct();
    }

    /**
     * Output widget.
     *
     * @param array $args
     * @param array $instance
     * @see WP_Widget
     *
     */
    public function widget($args, $instance)
    {
        ob_start();
        ?>

        <?php $dizibiz_portfolio_cat = array();
        for ($i = 1; $i <= 4; $i++) {
            $dizibiz_portfolio_cat_list = absint($instance['category_' . $i]);
            if (!empty($dizibiz_portfolio_cat_list)) {
                $dizibiz_portfolio_cat[] = absint($dizibiz_portfolio_cat_list);
            }
        }
        $dizibiz_portfolio_args = array();
        if (!empty($dizibiz_portfolio_cat)) {
            $dizibiz_portfolio_args = array(
                'post_type' => 'post',
                'cat' => $dizibiz_portfolio_cat,
                'ignore_sticky_posts' => true,
                'posts_per_page' => 16,
            );
        } ?>
        <div class="theme-gallery-tab theme-block">
            <div class="wrapper">
                <div class="column-row">
                    <div class="column column-12">
                        <div class="theme-primary-header theme-text-center">
                            <h2 class="entry-title entry-title-large">
                                <?php echo esc_html($instance['title']); ?> </h2>
                            <p> <?php echo esc_html($instance['description']); ?> </p>
                        </div>

                        <div class="gallery-tab-container">
                            <div class="gallery-tab-title">
                                <ul class="filter-group">
                                    <li><span class="filter" data-filter="*">
                                            <?php esc_html_e('show all', 'dizibiz') ?>
                                        </span></li>
                                    <?php for ($j = 0; $j < count($dizibiz_portfolio_cat); $j++) {
                                        $dizibiz_category = get_cat_name($dizibiz_portfolio_cat[$j]);
                                        $dizibiz_category_id = get_cat_id($dizibiz_category);
                                        if (!empty($dizibiz_category)) { ?>
                                            <li>
                                                <span class="filter"
                                                    data-filter="<?php echo esc_html('cat-' . $dizibiz_category_id) ?>"><?php echo esc_html($dizibiz_category, 'dizibiz') ?>
                                                </span>
                                            </li>
                                        <?php }
                                    } ?>
                                </ul>
                            </div>

                            <div class="gallery-tab-content">
                                <?php
                                $dizibiz_portfolio_post_query = new WP_Query($dizibiz_portfolio_args);
                                if ($dizibiz_portfolio_post_query->have_posts()):
                                    while ($dizibiz_portfolio_post_query->have_posts()):
                                        $dizibiz_portfolio_post_query->the_post();
                                        $dizibiz_cat_id = array();
                                        if (has_post_thumbnail()) {
                                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large');
                                            $featured_image = isset($featured_image[0]) ? $featured_image[0] : '';
                                        }
                                        $dizibiz_categories = get_the_category();
                                        foreach ($dizibiz_categories as $dizibiz_cat) {
                                            $dizibiz_cat_id[] = $dizibiz_cat->term_id;
                                        }
                                        $cat_ids = implode(' cat-', $dizibiz_cat_id);
                                        $dizibiz_single_cat_name = get_cat_name($cat_ids);
                                        ?>
                                        <div class="tab-content-item cat-<?php echo esc_html($cat_ids); ?>">
                                            <div class="data-bg data-bg-medium"
                                                data-background="<?php echo esc_url($featured_image); ?>"></div>
                                        </div>
                                        <!-- END .portfolio-masonry-entry-->
                                        <?php
                                    endwhile;
                                endif;
                                wp_reset_postdata();
                                ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="theme-gallery-popup">
                <div class="gallery-popup-content">
                    <img src="" alt="">
                    <button class="gallery-btn gallery-close">
                        <?php dizibiz_theme_svg('close'); ?>
                    </button>
                </div>

            </div>

        </div>
        <?php
        echo ob_get_clean();
    }
}