<?php
if (!defined('ABSPATH')) {
    exit;
}

class Dizibiz_Service_Widget extends Dizibiz_Widget_Base
{
    /**
     * Sets up a new widget instance.
     *
     * @since 1.0.0
     */
    public function __construct()
    {
        $icon_page_link = get_site_url() . '/twp-dizibiz-svg-icon-set';
        $this->widget_cssclass = 'widget_dizibiz_service_posts';
        $this->widget_description = __("Displays service posts with an image", 'dizibiz');
        $this->widget_id = 'dizibiz_service_posts';
        $this->widget_name = __('Dizibiz: Service Section', 'dizibiz');
        $this->settings = array(
            'title' => array(
                'type' => 'text',
                'label' => __('Title', 'dizibiz'),
            ),
            'description' => array(
                'type' => 'textarea',
                'label' => __('Section Description', 'dizibiz'),
            ),
            'button_text' => array(
                'type' => 'text',
                'label' => __('Button Text', 'dizibiz'),
            ),
            'button_url' => array(
                'type' => 'url',
                'label' => __('Button URL', 'dizibiz'),
            ),
            'service_icon_1' => array(
                'type' => 'text',
                'label' => __('Service Icon - 1', 'dizibiz'),
                'desc' => sprintf(__('For SVG Icon  <a href="%s" target="_blank">Click Here</a> to see inbuild icon set', 'dizibiz'), $icon_page_link),
            ),
            'page_id_1' => array(
                'label' => esc_html__('Select Page - 1', 'dizibiz'),
                'type'  => 'dropdown-pages',
                'std'   => '',
            ),
            'service_icon_2' => array(
                'type' => 'text',
                'label' => __('Service Icon - 2', 'dizibiz'),
                'desc' => sprintf(__('For SVG Icon  <a href="%s" target="_blank">Click Here</a> to see inbuild icon set', 'dizibiz'), $icon_page_link),
            ),
            'page_id_2' => array(
                'label' => esc_html__('Select Page - 2', 'dizibiz'),
                'type'  => 'dropdown-pages',
            ),
            'service_icon_3' => array(
                'type' => 'text',
                'label' => __('Service Icon - 3', 'dizibiz'),
                'desc' => sprintf(__('For SVG Icon  <a href="%s" target="_blank">Click Here</a> to see inbuild icon set', 'dizibiz'), $icon_page_link),
            ),
            'page_id_3' => array(
                'label' => esc_html__('Select Page - 3', 'dizibiz'),
                'type'  => 'dropdown-pages',
            ),
            'service_icon_4' => array(
                'type' => 'text',
                'label' => __('Service Icon - 4', 'dizibiz'),
                'desc' => sprintf(__('For SVG Icon  <a href="%s" target="_blank">Click Here</a> to see inbuild icon set', 'dizibiz'), $icon_page_link),
            ),
            'page_id_4' => array(
                'label' => esc_html__('Select Page - 4', 'dizibiz'),
                'type'  => 'dropdown-pages',
            ),
            'service_icon_5' => array(
                'type' => 'text',
                'label' => __('Service Icon - 5', 'dizibiz'),
                'desc' => sprintf(__('For SVG Icon  <a href="%s" target="_blank">Click Here</a> to see inbuild icon set', 'dizibiz'), $icon_page_link),
            ),
            'page_id_5' => array(
                'label' => esc_html__('Select Page - 5', 'dizibiz'),
                'type'  => 'dropdown-pages',
            ),

        );
        parent::__construct();
    }

    /**
     * Query the posts and return them.
     * @param array $args
     * @param array $instance
     * @return WP_Query
     */
    public function get_posts($args, $instance)
    {
        $dizibiz_service_page = array();
        for ($i = 1; $i <= 5; $i++) {
            $dizibiz_service_page_list[] = absint($instance['page_id_' . $i]);
        }
        $query_args = array(
            'posts_per_page' => 5,
            'orderby' => 'post__in',
            'post_type' => 'page',
            'post__in' => $dizibiz_service_page_list,
        );

        return new WP_Query(apply_filters('dizibiz_service_posts_query_args', $query_args));
    }

    /**
     * Output widget.
     *
     * @param array $args
     * @param array $instance
     * @see WP_Widget
     *
     */
    public function widget($args, $instance)
    {
        ob_start();
        if (($posts = $this->get_posts($args, $instance)) && $posts->have_posts()) {
            $i = 1;
?>

            <div class="theme-service theme-block">
                <div class="wrapper">
                    <div class="column-row">
                        <div class="column column-4 column-md-6 column-xs-12 mb-32">
                            <div class="service-content-container">
                                <h2 class="entry-title entry-title-big">
                                    <?php echo esc_html($instance['title']); ?>
                                </h2>


                                <p> <?php echo esc_html($instance['description']); ?> </p>

                                <button class="theme-primary-btn">
                                    <a href="<?php echo esc_html($instance['button_url']); ?>"> <?php echo esc_html($instance['button_text']); ?> </a>
                                </button>

                            </div>
                        </div>
                        <?php while ($posts->have_posts()) : $posts->the_post(); ?>
                            <div class="column column-4 column-md-6 column-xs-12 mb-32">
                                <div class="service-content-container">
                                    <?php if (!empty($instance['service_icon_' . $i])) { ?>
                                        <?php dizibiz_theme_svg($instance['service_icon_' . $i]); ?>
                                    <?php } ?>
                                    <h2 class="entry-title entry-title-medium">
                                        <?php the_title(); ?>
                                    </h2>

                                    <?php the_excerpt(); ?>
                                </div>
                            </div>
                        <?php $i++;
                        endwhile;
                        wp_reset_postdata(); ?>

                    </div>
                </div>
            </div>

<?php
        }
        echo ob_get_clean();
    }
}
