<?php
if (!defined('ABSPATH')) {
    exit;
}

class Dizibiz_Testimonial_Widget extends Dizibiz_Widget_Base
{
    /**
     * Sets up a new widget instance.
     *
     * @since 1.0.0
     */
    public function __construct()
    {
        $this->widget_cssclass = 'widget_dizibiz_testimonial_posts';
        $this->widget_description = __("Displays testimonial section with an image", 'dizibiz');
        $this->widget_id = 'dizibiz_testimonial_posts';
        $this->widget_name = __('Dizibiz: Testimonial Section', 'dizibiz');
        $this->settings = array(
            'title' => array(
                'type' => 'text',
                'label' => __('Title', 'dizibiz'),
            ),
            'description' => array(
                'type' => 'textarea',
                'label' => __('Section Description', 'dizibiz'),
            ),
            'button_text' => array(
                'type' => 'text',
                'label' => __('Button Text', 'dizibiz'),
            ),
            'button_url' => array(
                'type' => 'url',
                'label' => __('Button URL', 'dizibiz'),
            ),
            'page_id_1' => array(
                'label' => esc_html__('Select Page - 1', 'dizibiz'),
                'type' => 'dropdown-pages',
                'std' => '',
            ),
            'page_id_2' => array(
                'label' => esc_html__('Select Page - 2', 'dizibiz'),
                'type' => 'dropdown-pages',
                'std' => '',
            ),
            'page_id_3' => array(
                'label' => esc_html__('Select Page - 3', 'dizibiz'),
                'type' => 'dropdown-pages',
                'std' => '',
            ),
            'page_id_4' => array(
                'label' => esc_html__('Select Page - 4', 'dizibiz'),
                'type' => 'dropdown-pages',
                'std' => '',
            ),
            'page_id_5' => array(
                'label' => esc_html__('Select Page - 5', 'dizibiz'),
                'type' => 'dropdown-pages',
                'std' => '',
            ),

        );
        parent::__construct();
    }

    /**
     * Output widget.
     *
     * @param array $args
     * @param array $instance
     * @see WP_Widget
     *
     */
    public function widget($args, $instance)
    {
        ob_start();
        ?>

        <div class="theme-testimonial theme-block">
            <div class="wrapper">
                <div class="column-row">
                    <div class="column column-5 column-sm-12">
                        <h2 class="entry-title entry-title-big">

                            <?php echo esc_html($instance['title']); ?>
                        </h2>

                        <p>
                            <?php echo esc_html($instance['description']); ?>
                        </p>

                        <button class="theme-primary-btn">
                            <a href="<?php echo esc_html($instance['button_url']); ?>"> <?php echo esc_html($instance['button_text']); ?> </a>

                        </button>
                    </div>

                    <?php $dizibiz_testimonial_page = array();
                    for ($i = 1; $i <= 5; $i++) {
                        $dizibiz_testimonial_page_list[] = absint($instance['page_id_' . $i]);
                    }
                    $dizibiz_testimonial_args = array(
                        'posts_per_page' => 5,
                        'orderby' => 'post__in',
                        'post_type' => 'page',
                        'post__in' => $dizibiz_testimonial_page_list,
                    ); ?>

                    <div class="column column-7 column-sm-12">
                        <div class="testimonial-carousel mySwiper">
                            <div class="swiper-wrapper">
                                <?php
                                $dizibiz_testimonial_post_query = new WP_Query($dizibiz_testimonial_args);
                                if ($dizibiz_testimonial_post_query->have_posts()):
                                    while ($dizibiz_testimonial_post_query->have_posts()):
                                        $dizibiz_testimonial_post_query->the_post();
                                        if (has_post_thumbnail()) {
                                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large');
                                            $featured_image = isset($featured_image[0]) ? $featured_image[0] : '';
                                        }
                                        ?>
                                        <div class="swiper-slide">
                                            <div class="testimonial-item">
                                                <div class="testimonial-detail">
                                                    <?php dizibiz_theme_svg('modern-quote'); ?>

                                                    <h2 class="entry-title entry-title-normal line-clamp line-clamp-5">
                                                        <?php the_title(); ?>
                                                    </h2>
                                                </div>

                                                <div class="data-bg data-bg-small"
                                                    data-background="<?php echo esc_url($featured_image); ?>"></div>

                                            </div>
                                        </div>
                                        <?php
                                    endwhile;
                                endif;
                                wp_reset_postdata();
                                ?>

                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>


        <?php
        echo ob_get_clean();
    }
}